@@ -163,6 +163,9 @@ class TaskDetails(BaseModel):
     report_list: Optional[List[str]]
     minimized_stack_depth: Optional[int]
     coverage_filter: Optional[str]
+    target_assembly: Optional[str]
+    target_class: Optional[str]
+    target_method: Optional[str]
 
 
 class TaskPool(BaseModel):
@@ -325,6 +328,9 @@ CONTAINER_DEF = Optional[Union[SyncedDir, List[SyncedDir]]]
 class ClientCredentials(BaseModel):
     client_id: UUID
     client_secret: str
+    resource: str
+    tenant: str
+    multi_tenant_domain: Optional[str]
 
 
 class AgentConfig(BaseModel):
@@ -336,6 +342,7 @@ class AgentConfig(BaseModel):
     microsoft_telemetry_key: Optional[str]
     multi_tenant_domain: Optional[str]
     instance_id: UUID
+    managed: Optional[bool] = Field(default=True)
 
 
 class TaskUnitConfig(BaseModel):
@@ -378,6 +385,9 @@ class TaskUnitConfig(BaseModel):
     report_list: Optional[List[str]]
     minimized_stack_depth: Optional[int]
     coverage_filter: Optional[str]
+    target_assembly: Optional[str]
+    target_class: Optional[str]
+    target_method: Optional[str]
 
     # from here forwards are Container definitions.  These need to be inline
     # with TaskDefinitions and ContainerTypes
@@ -668,9 +678,9 @@ class Scaleset(BaseModel):
 
 class AutoScale(BaseModel):
     scaleset_id: UUID
-    min: int = Field(ge=1)
+    min: int = Field(ge=0)
     max: int = Field(ge=1)
-    default: int = Field(ge=1)
+    default: int = Field(ge=0)
     scale_out_amount: int = Field(ge=1)
     scale_out_cooldown: int = Field(ge=1)
     scale_in_amount: int = Field(ge=1)
@@ -872,7 +882,7 @@ class InstanceConfig(BaseModel):
     admins: Optional[List[UUID]] = None
 
     # if set, only admins can manage pools or scalesets
-    require_admin_privileges: bool = Field(default=True)
+    require_admin_privileges: bool = Field(default=False)
 
     allowed_aad_tenants: List[UUID]
     network_config: NetworkConfig = Field(default_factory=NetworkConfig)
@@ -880,6 +890,12 @@ class InstanceConfig(BaseModel):
         default_factory=NetworkSecurityGroupConfig
     )
     extensions: Optional[AzureVmExtensionConfig]
+    default_windows_vm_image: str = Field(
+        default="MicrosoftWindowsDesktop:Windows-10:win10-21h2-pro:latest"
+    )
+    default_linux_vm_image: str = Field(
+        default="Canonical:0001-com-ubuntu-server-focal:20_04-lts:latest"
+    )
     proxy_vm_sku: str = Field(default="Standard_B2s")
     api_access_rules: Optional[Dict[Endpoint, ApiAccessRule]] = None
     group_membership: Optional[Dict[PrincipalID, List[GroupId]]] = None
