@@ -92,7 +92,7 @@ class PoolCreate(BaseRequest):
     os: OS
     arch: Architecture
     managed: bool
-    client_id: Optional[UUID]
+    object_id: Optional[UUID]
     autoscale: Optional[AutoScaleConfig]
 
 
@@ -170,9 +170,9 @@ class ScalesetUpdate(BaseRequest):
 
 
 class AutoScaleOptions(BaseModel):
-    min: int = Field(ge=1)
+    min: int = Field(ge=0)
     max: int = Field(ge=1)
-    default: int = Field(ge=1)
+    default: int = Field(ge=0)
     scale_out_amount: int = Field(ge=1)
     scale_out_cooldown: int = Field(ge=1)
     scale_in_amount: int = Field(ge=1)
@@ -182,7 +182,7 @@ class AutoScaleOptions(BaseModel):
 class ScalesetCreate(BaseRequest):
     pool_name: PoolName
     vm_sku: str
-    image: str
+    image: Optional[str]
     region: Optional[Region]
     size: int = Field(ge=1)
     spot_instances: bool
