@@ -11,9 +11,13 @@ from onefuzztypes.models import InstanceConfig
 
 class TestInstanceConfig(unittest.TestCase):
     def test_with_admins(self) -> None:
-        no_admins = InstanceConfig(admins=None)
-        with_admins = InstanceConfig(admins=[UUID(int=0)])
-        with_admins_2 = InstanceConfig(admins=[UUID(int=1)])
+        no_admins = InstanceConfig(admins=None, allowed_aad_tenants=[UUID(int=0)])
+        with_admins = InstanceConfig(
+            admins=[UUID(int=0)], allowed_aad_tenants=[UUID(int=0)]
+        )
+        with_admins_2 = InstanceConfig(
+            admins=[UUID(int=1)], allowed_aad_tenants=[UUID(int=0)]
+        )
 
         no_admins.update(with_admins)
         self.assertEqual(no_admins.admins, None)
